==> rulee-ts-0.12.0.tgz: package/lib/esm/properties/group-of-properties-impl.js <==
import { AbstractPropertyImpl } from "./abstract-property-impl";
export class GroupOfPropertiesImpl extends AbstractPropertyImpl {
    constructor(id, properties, updateHandler) {
        super(updateHandler);
        this.id = id;
        this.properties = properties;
        this.propertiesAsList = Object.keys(this.properties).map(propKey => this.properties[propKey]);
    }
    internallySyncUpdate() {
        throw new Error("Method not implemented.");
    }
    internallyAsyncUpdate() {
        throw new Error("Method not implemented.");
    }
    isValid() {
        return super.isValid() && Object.keys(this.properties).every(k => this.properties[k].isValid());
    }
    isProcessing() {
        return Object.keys(this.properties).some(k => this.properties[k].isProcessing());
    }
    isReadOnly() {
        return Object.keys(this.properties).every(k => this.properties[k].isReadOnly());
    }
    isAsynchronous() {
        return Object.keys(this.properties).some(k => this.properties[k].isAsynchronous());
    }
    setToInitialState() {
        this.propertiesAsList.forEach(prop => prop.setToInitialState());
    }
    exportData() {
        return Object.keys(this.properties).reduce((res, cur) => {
            res[cur] = this.properties[cur].exportData();
            return res;
        }, {});
    }
    importData(data) {
        if (data != null) {
            Object.keys(this.properties).forEach(key => {
                this.properties[key].importData(data[key]);
            });
        }
        this.needsAnUpdate();
    }
}

==> rulee-ts-0.14.0.tgz: package/lib/esm/properties/group-of-properties-impl.js <==
import { AbstractParentPropertyImpl } from "./abstract-parent-property-impl";
export class GroupOfPropertiesImpl extends AbstractParentPropertyImpl {
    constructor(id, properties, updateHandler) {
        super(updateHandler);
        this.id = id;
        this.properties = properties;
        this.propertiesAsList = Object.keys(this.properties).map(propKey => this.properties[propKey]);
    }
    getChildren() {
        return this.propertiesAsList;
    }
    internallySyncUpdate() {
        throw new Error("Method not implemented.");
    }
    internallyAsyncUpdate() {
        throw new Error("Method not implemented.");
    }
    isProcessing() {
        return Object.keys(this.properties).some(k => this.properties[k].isProcessing());
    }
    isReadOnly() {
        return Object.keys(this.properties).every(k => this.properties[k].isReadOnly());
    }
    isAsynchronous() {
        return Object.keys(this.properties).some(k => this.properties[k].isAsynchronous());
    }
    setDataToInitialState() {
        this.propertiesAsList.forEach(prop => prop.setToInitialState());
    }
    exportData() {
        return Object.keys(this.properties).reduce((res, cur) => {
            res[cur] = this.properties[cur].exportData();
            return res;
        }, {});
    }
    importData(data) {
        if (data != null) {
            Object.keys(this.properties).forEach(key => {
                this.properties[key].importData(data[key]);
            });
        }
        this.needsAnUpdate();
    }
}
